==> SCFiler2-0.09.zip: SCFiler2/SCFiler2/Action.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using SCFiler2.Util;

namespace SCFiler2.Action {
	public abstract class Action {
		static public Action ExitApplication = new ExitApplication();
		static public Action CopyToAnotherFileView = new CopyToAnotherFileVIew();
		static public Action MoveToAnothierFileView = new MoveToAnotherFileView();
		static public Action MoveToRecycle = new MoveToRecycle();
		static public Action DeleteSelectedItem = new DeleteSelectedItem();
		static public Action ExecuteFocusedItem = new ExecuteFocusedItem();
		static public Action MoveToParentFolder = new MoveToParentFolder();
		static public Action setFocusToLeftFileView = new setFocusToLeftFileView();
		static public Action setFocusToRightFileView = new setFocusToRightFileView();
		static public Action OpenByExplorer = new OpenByExplorer();
		static public Action MoveToDriveRoot = new MoveToDriveRoot();
		static public Action AddToJumpFolder = new AddToJumpFolder();
		static public Action GoToJumpFolder = new GoToJumpFolder();
		static public Action GoToSameFolderAsAnotherView = new GoToSameFolderAsAnotherView();

		static public Action[] All_Action = { ExitApplication, CopyToAnotherFileView, MoveToAnothierFileView,
			MoveToRecycle, DeleteSelectedItem, ExecuteFocusedItem, MoveToParentFolder, setFocusToLeftFileView, 
			setFocusToRightFileView, OpenByExplorer, MoveToDriveRoot, AddToJumpFolder, GoToJumpFolder,
			GoToSameFolderAsAnotherView};

		abstract public string DisplayString { get;}

		abstract public void execute();

	}
}

==> SCFiler2-0.11.2.zip: SCFiler2/SCFiler2/Action.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using SCFiler2.Util;

namespace SCFiler2.Action {
	public abstract class Action {
		static public Action ExitApplication = new ExitApplication();
		static public Action CopyToAnotherFileView = new CopyToAnotherFileVIew();
		static public Action MoveToAnothierFileView = new MoveToAnotherFileView();
		static public Action MoveToRecycle = new MoveToRecycle();
		static public Action DeleteSelectedItem = new DeleteSelectedItem();
		static public Action ExecuteFocusedItem = new ExecuteFocusedItem();
		static public Action MoveToParentFolder = new MoveToParentFolder();
		static public Action setFocusToLeftFileView = new setFocusToLeftFileView();
		static public Action setFocusToRightFileView = new setFocusToRightFileView();
		static public Action OpenByExplorer = new OpenByExplorer();
		static public Action MoveToDriveRoot = new MoveToDriveRoot();
		static public Action AddToJumpFolder = new AddToJumpFolder();
		static public Action GoToJumpFolder = new GoToJumpFolder();
		static public Action GoToSameFolderAsAnotherView = new GoToSameFolderAsAnotherView();
		static public Action CreateFolder = new CreateFolder();
		static public Action IncrementalSearch = new IncrementalSearch();

		static public Action[] All_Action = { ExitApplication, CopyToAnotherFileView, MoveToAnothierFileView,
			MoveToRecycle, DeleteSelectedItem, ExecuteFocusedItem, MoveToParentFolder, setFocusToLeftFileView, 
			setFocusToRightFileView, OpenByExplorer, MoveToDriveRoot, AddToJumpFolder, GoToJumpFolder,
			GoToSameFolderAsAnotherView, CreateFolder, IncrementalSearch};

		abstract public string DisplayString { get;}

		abstract public void execute();

	}
}
